#[non_exhaustive]pub struct FrameDetails<B: ByteData> {
pub color_icc_profile: Option<B>,
pub color_cicp: Option<[u8; 4]>,
pub info_bit_depth: Option<u8>,
pub info_alpha_channel: Option<bool>,
pub info_grayscale: Option<bool>,
pub n_frame: Option<u64>,
}Expand description
More information about a frame
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.color_icc_profile: Option<B>ICC color profile
color_cicp: Option<[u8; 4]>Coding-independent code points (HDR information)
info_bit_depth: Option<u8>Bit depth per channel
Only set if it can differ for the format
info_alpha_channel: Option<bool>Image has alpha channel
Only set if it can differ for the format
info_grayscale: Option<bool>Image uses grayscale mode
Only set if it can differ for the format
n_frame: Option<u64>Implementations
Sourceimpl<B: ByteData> FrameDetails<B>
impl<B: ByteData> FrameDetails<B>
pub fn into_fungible(self) -> FrameDetails<FungibleMemory>
pub fn into_other<O: ByteData>( self, ) -> Result<FrameDetails<O>, MemoryAllocationError>
pub async fn initial_seal(&mut self) -> Result<(), MemoryAllocationError>
pub async fn final_seal(&mut self) -> Result<(), MemoryAllocationError>