#[non_exhaustive]pub struct ImageDetails<B: ByteData> {
pub width: u32,
pub height: u32,
pub dimensions_inch: Option<(f64, f64)>,
pub info_format_name: Option<String>,
pub info_dimensions_text: Option<String>,
pub metadata_exif: Option<B>,
pub metadata_xmp: Option<B>,
pub metadata_key_value: Option<BTreeMap<String, String>>,
pub transformation_ignore_exif: bool,
pub transformation_orientation: Option<Orientation>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.width: u32Early dimension information.
This information is often correct. However, it should only be used for an early rendering estimates. For everything else, the specific frame information should be used.
height: u32dimensions_inch: Option<(f64, f64)>Image dimensions in inch
info_format_name: Option<String>info_dimensions_text: Option<String>Textual description of the image dimensions
metadata_exif: Option<B>metadata_xmp: Option<B>metadata_key_value: Option<BTreeMap<String, String>>transformation_ignore_exif: booltransformation_orientation: Option<Orientation>Explicit orientation. If None check Exif or XMP.
Implementations
Sourceimpl<B: ByteData> ImageDetails<B>
impl<B: ByteData> ImageDetails<B>
pub fn new(width: u32, height: u32) -> Self
pub fn into_fungible(self) -> ImageDetails<FungibleMemory>
pub fn into_other<O: ByteData>( self, ) -> Result<ImageDetails<O>, MemoryAllocationError>
pub async fn initial_seal(&mut self) -> Result<(), MemoryAllocationError>
pub async fn final_seal(&mut self) -> Result<(), MemoryAllocationError>